@@ -139,7 +139,7 @@ class UserTemplate:
 
     Attributes
     ----------
-    filename (str): user template file name i.e /home_dir/.templateapp/user_templates.yaml
+    filename (str): user template file name i.e /home_dir/.geekstrident/templateapp/user_templates.yaml
     status (str): a status message.
     content (str): user template file content.
 
@@ -152,17 +152,17 @@ class UserTemplate:
     write(template_name, data) -> str
     """
     def __init__(self):
-        self.filename = str(PurePath(Path.home(), '.templateapp', 'user_templates.yaml'))
+        self.filename = Data.user_template_filename
         self.status = ''
         self.content = ''
 
     def is_exist(self):
-        """return True if /home_dir/.templateapp/user_templates.yaml exists"""
+        """return True if /home_dir/.geekstrident/templateapp/user_templates.yaml exists"""
         node = Path(self.filename)
         return node.exists()
 
     def create(self, confirmed=True):
-        """create /home_dir/.templateapp/user_templates.yaml if it IS NOT existed.
+        """create /home_dir/.geekstrident/templateapp/user_templates.yaml if it IS NOT existed.
 
         Parameters
         ----------
@@ -211,7 +211,7 @@ class UserTemplate:
             create_msgbox(title=title, error=error)
 
     def read(self):
-        """return content of /home_dir/.templateapp/user_templates.yaml"""
+        """return content of /home_dir/.geekstrident/templateapp/user_templates.yaml"""
         if self.is_exist():
             with open(self.filename) as stream:
                 self.content = stream.read()
@@ -269,7 +269,7 @@ class UserTemplate:
             return ''
 
     def write(self, template_name, template):
-        """store template to /home_dir/.templateapp/user_templates.yaml
+        """store template to /home_dir/.geekstrident/templateapp/user_templates.yaml
 
         Parameters
         ----------
